---
name: 🚀Feature request
about: Suggest an idea for this project
title: ''
labels: feature request
assignees: hankcs

---

<!--
Thank you for suggesting an idea to make HanLP better.
Please fill in the template below to bypass our spam filter.  
以下必填，否则直接关闭。
-->

**Describe the feature and the current behavior/state.**

**Will this change the current api? How?**

**Who will benefit with this feature?**

**Are you willing to contribute it (Yes/No):**

**System information**
- OS Platform and Distribution (e.g., Linux Ubuntu 16.04):
- Python version:
- HanLP version:

**Any other info**

* [ ] I've carefully completed this form.
